@@ -19,6 +19,8 @@ class Ram:
         transport = Transport(cache=InMemoryCache(timeout=(3600 * 24)))
         self.uploads_client = zeep_client('http://41.21.176.123/RAMConnectV2/Uploads/CustomerPortalWS.asmx?WSDL',
                                           transport=transport)
+        self.tracking_client = zeep_client('http://services.ramgroup.co.za/ramconnectv2/Tracking/TrackingWS.asmx?WSDL',
+                                           transport=transport)
         self.tsm_client = zeep_client('http://41.21.176.123/ramconnectv2/Tracking/ServiceMessagesWS.asmx?WSDL',
                                       transport=transport)
         self.user_id = user_id or os.environ.get('RAM_USER_ID')
@@ -169,3 +171,74 @@ class Ram:
         :return:
         """
         return self.tsm_client.service.PODImagesAsPDF(self.user_id, self.token, *args)
+
+
+    """
+    Tracking web service
+    """
+
+    @refresh_token
+    def consignment_details(self, *args):
+        """
+        ConsignmentDetails from ConsignmentID
+        :param args: The unique ConsignmentID assigned to your consignment
+        :return:
+        """
+        return self.tracking_client.service.ConsignmentDetails(self.user_id, self.token, *args)
+
+    @refresh_token
+    def consignment_details_by_shipper_reference(self, *args):
+        return self.tracking_client.service.ConsignmentDetailsByShipperReference(self.user_id, self.token, *args)
+
+    @refresh_token
+    def consignments_consigned_by_day(self, *args):
+        return self.tracking_client.service.ConsignmentsConsignedByDay(self.user_id, self.token, *args)
+
+    @refresh_token
+    def consignments_delivered_by_day(self, *args):
+        return self.tracking_client.service.ConsignmentsDeliveredByDay(self.user_id, self.token, *args)
+
+    @refresh_token
+    def consignments_tracking_status(self, *args):
+        return  self.tracking_client.service.ConsignmentsTrackingStatus(self.user_id, self.token, *args)
+
+    @refresh_token
+    def consignments_tracking_status_by_shipper_references(self, *args):
+        return self.tracking_client.service.ConsignmentsTrackingStatusByShipperReferences(self.user_id, self.token,
+                                                                                          *args)
+
+    @refresh_token
+    def consignment_tracking(self, *args):
+        return self.tracking_client.service.ConsignmentTracking(self.user_id, self.token, *args)
+
+    @refresh_token
+    def consignment_tracking_by_shipper_reference(self, *args):
+        return self.tracking_client.service.ConsignmentTrackingByShipperReference(self.user_id, self.token, *args)
+
+    @refresh_token
+    def get_quote_v3(self, *args):
+        return self.tracking_client.service.GetQuoteV3(self.user_id, self.token, *args)
+
+    @refresh_token
+    def pod_image(self, *args):
+        return self.tracking_client.service.PODImage(self.user_id, self.token, *args)
+
+    @refresh_token
+    def pod_image_by_index(self, *args):
+        return self.tracking_client.service.PODImageByIndex(self.user_id, self.token, *args)
+
+    @refresh_token
+    def pod_images(self, *args):
+        return self.tracking_client.service.PODImages(self.user_id, self.token, *args)
+
+    @refresh_token
+    def pod_images_list(self, *args):
+        return self.tracking_client.service.PODImagesList(self.user_id, self.token, *args)
+
+    @refresh_token
+    def suburbs_download(self, *args):
+        return self.tracking_client.service.SuburbsDownload(self.user_id, self.token, *args)
+
+    @refresh_token
+    def suburb_search(self, *args):
+        return self.tracking_client.service.SuburbSearch(self.user_id, self.token, *args)
